@@ -2,20 +2,21 @@
  *
  * Copyright (C) 2013-2014 Stefano Karapetsas
  *
- *  This file is part of MATE Applets.
+ * This file is part of MATE Applets.
  *
- *  MATE Applets is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- *  MATE Applets is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with MATE Applets.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Authors:
  *      Stefano Karapetsas <stefano@karapetsas.com>
@@ -60,7 +61,7 @@ typedef struct
 
     GtkLabel          *label;
     GtkImage          *image;
-    GtkHBox           *hbox;
+    GtkBox            *box;
 
     gchar             *command;
     gint               interval;
@@ -88,7 +89,7 @@ command_applet_destroy (MatePanelApplet *applet_widget, CommandApplet *command_a
 
     if (command_applet->timeout_id != 0)
     {
-        g_source_remove(command_applet->timeout_id);
+        g_source_remove (command_applet->timeout_id);
         command_applet->timeout_id = 0;
     }
 
@@ -135,7 +136,7 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
                                                      GTK_STOCK_CLOSE,
                                                      GTK_RESPONSE_CLOSE,
                                                      NULL));
-    table = gtk_table_new (4, 2, FALSE);
+    table = GTK_TABLE (gtk_table_new (4, 2, FALSE));
     gtk_table_set_row_spacings (table, 12);
     gtk_table_set_col_spacings (table, 12);
 
@@ -143,7 +144,12 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
     gtk_container_set_border_width (GTK_CONTAINER (dialog), 10);
 
     widget = gtk_label_new (_("Command:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (widget), 1.0);
+    gtk_label_set_yalign (GTK_LABEL (widget), 0.5);
+#else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
+#endif
     gtk_table_attach (table, widget, 1, 2, 0, 1,
                       GTK_FILL, GTK_FILL,
                       0, 0);
@@ -154,7 +160,12 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
                       0, 0);
 
     widget = gtk_label_new (_("Interval (seconds):"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (widget), 1.0);
+    gtk_label_set_yalign (GTK_LABEL (widget), 0.5);
+#else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
+#endif
     gtk_table_attach (table, widget, 1, 2, 1, 2,
                       GTK_FILL, GTK_FILL,
                       0, 0);
@@ -165,7 +176,12 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
                       0, 0);
 
     widget = gtk_label_new (_("Maximum width (chars):"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gtk_label_set_xalign (GTK_LABEL (widget), 1.0);
+    gtk_label_set_yalign (GTK_LABEL (widget), 0.5);
+#else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
+#endif
     gtk_table_attach (table, widget, 1, 2, 2, 3,
                       GTK_FILL, GTK_FILL,
                       0, 0);
@@ -180,7 +196,7 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
                       GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
                       0, 0);
 
-    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)), table, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)), GTK_WIDGET (table), TRUE, TRUE, 0);
 
     g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), dialog);
 
@@ -220,7 +236,7 @@ settings_width_changed (GSettings *settings, gchar *key, CommandApplet *command_
     command_applet->width = width;
 
     /* execute command to start new timer */
-    command_execute(command_applet);
+    command_execute (command_applet);
 }
 
 static void
@@ -239,7 +255,7 @@ settings_interval_changed (GSettings *settings, gchar *key, CommandApplet *comma
     /* stop current timer */
     if (command_applet->timeout_id != 0)
     {
-        g_source_remove(command_applet->timeout_id);
+        g_source_remove (command_applet->timeout_id);
         command_applet->timeout_id = 0;
     }
 
@@ -339,21 +355,21 @@ command_applet_fill (MatePanelApplet* applet)
     command_applet->command = g_settings_get_string (command_applet->settings, COMMAND_KEY);
     command_applet->width = g_settings_get_int (command_applet->settings, WIDTH_KEY);
 
-    command_applet->hbox = gtk_hbox_new (FALSE, 0);
-    command_applet->image = gtk_image_new_from_icon_name (APPLET_ICON, 24);
-    command_applet->label = gtk_label_new (ERROR_OUTPUT);
+    command_applet->box = GTK_BOX (gtk_hbox_new (FALSE, 0));
+    command_applet->image = GTK_IMAGE (gtk_image_new_from_icon_name (APPLET_ICON, 24));
+    command_applet->label = GTK_LABEL (gtk_label_new (ERROR_OUTPUT));
     command_applet->timeout_id = 0;
 
     /* we add the Gtk label into the applet */
-    gtk_box_pack_start (GTK_BOX (command_applet->hbox),
+    gtk_box_pack_start (command_applet->box,
                         GTK_WIDGET (command_applet->image),
                         TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (command_applet->hbox),
+    gtk_box_pack_start (command_applet->box,
                         GTK_WIDGET (command_applet->label),
                         TRUE, TRUE, 0);
 
     gtk_container_add (GTK_CONTAINER (applet),
-                       GTK_WIDGET (command_applet->hbox));
+                       GTK_WIDGET (command_applet->box));
 
     gtk_widget_show_all (GTK_WIDGET (command_applet->applet));
 
