@@ -43,7 +43,6 @@
 #endif
 
 struct _MateWeatherPrefPrivate {
-	GtkWidget* basic_detailed_btn;
 	GtkWidget* basic_temp_combo;
 	GtkWidget* basic_speed_combo;
 	GtkWidget* basic_dist_combo;
@@ -188,10 +187,6 @@ static gboolean update_dialog(MateWeatherPref* pref)
 
     gtk_combo_box_set_active(GTK_COMBO_BOX(pref->priv->basic_dist_combo), gw_applet->mateweather_pref.distance_unit - 2);
 
-	#if 0
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pref->priv->basic_detailed_btn), gw_applet->mateweather_pref.detailed);
-	#endif
-
 	#ifdef RADARMAP
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pref->priv->basic_radar_btn), gw_applet->mateweather_pref.radar_enabled);
 
@@ -281,7 +276,7 @@ static void load_locations(MateWeatherPref* pref)
 	GtkCellRenderer* cell_renderer;
 	WeatherLocation* current_location;
 
-	/* Add a colum for the locations */
+	/* Add a column for the locations */
 	cell_renderer = gtk_cell_renderer_text_new();
 	column = gtk_tree_view_column_new_with_attributes("not used", cell_renderer, "text", MATEWEATHER_XML_COL_LOC, NULL);
 	gtk_tree_view_append_column(tree, column);
@@ -355,18 +350,6 @@ static void auto_update_toggled(GtkToggleButton* button, MateWeatherPref* pref)
 	}
 }
 
-#if 0
-	static void detailed_toggled(GtkToggleButton* button, MateWeatherPref* pref)
-	{
-		MateWeatherApplet* gw_applet = pref->priv->applet;
-		gboolean toggled;
-
-		toggled = gtk_toggle_button_get_active(button);
-		gw_applet->mateweather_pref.detailed = toggled;
-		g_settings_set_boolean (gw_applet->settings, "enable-detailed-forecast", toggled);
-	}
-#endif
-
 static void temp_combo_changed_cb(GtkComboBox* combo, MateWeatherPref* pref)
 {
 	MateWeatherApplet* gw_applet = pref->priv->applet;
@@ -562,7 +545,7 @@ static gboolean free_data(GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* i
 }
 
 
-static GtkWidget* create_hig_catagory(GtkWidget* main_box, gchar* title)
+static GtkWidget* create_hig_category(GtkWidget* main_box, gchar* title)
 {
 	GtkWidget* vbox;
 	GtkWidget* vbox2;
@@ -575,7 +558,11 @@ static GtkWidget* create_hig_catagory(GtkWidget* main_box, gchar* title)
 
 	tmp = g_strdup_printf ("<b>%s</b>", title);
 	label = gtk_label_new (NULL);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
 	gtk_label_set_markup (GTK_LABEL (label), tmp);
 	g_free (tmp);
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
@@ -867,7 +854,11 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	temp_label = gtk_label_new_with_mnemonic (_("_Temperature unit:"));
 	gtk_label_set_use_markup (GTK_LABEL (temp_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (temp_label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (temp_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (temp_label), 0.0, 0.5);
+#endif
 	gtk_widget_show (temp_label);
 
 	temp_combo = gtk_combo_box_text_new ();
@@ -889,7 +880,11 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	speed_label = gtk_label_new_with_mnemonic (_("_Wind speed unit:"));
 	gtk_label_set_use_markup (GTK_LABEL (speed_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (speed_label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (speed_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (speed_label), 0.0, 0.5);
+#endif
 	gtk_widget_show (speed_label);
 
 	speed_combo = gtk_combo_box_text_new ();
@@ -916,7 +911,11 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	pres_label = gtk_label_new_with_mnemonic (_("_Pressure unit:"));
 	gtk_label_set_use_markup (GTK_LABEL (pres_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (pres_label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (pres_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (pres_label), 0.0, 0.5);
+#endif
 	gtk_widget_show (pres_label);
 
 	pres_combo = gtk_combo_box_text_new ();
@@ -946,7 +945,11 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	dist_label = gtk_label_new_with_mnemonic (_("_Visibility unit:"));
 	gtk_label_set_use_markup (GTK_LABEL (dist_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (dist_label), GTK_JUSTIFY_LEFT);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (dist_label), 0, 0.5);
+#endif
 	gtk_widget_show (dist_label);
 
 	dist_combo = gtk_combo_box_text_new ();
@@ -1043,19 +1046,13 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 		g_signal_connect (G_OBJECT (pref->priv->basic_show_notifications_btn), "toggled", G_CALLBACK (show_notifications_toggled), pref);
     #endif
 
-	frame = create_hig_catagory (pref_basic_vbox, _("Update"));
+	frame = create_hig_category (pref_basic_vbox, _("Update"));
 
 	pref_basic_update_hbox = gtk_hbox_new (FALSE, 12);
 
 	pref_basic_update_lbl = gtk_label_new_with_mnemonic (_("_Automatically update every:"));
 	gtk_widget_show (pref_basic_update_lbl);
 
-
-/*
-	gtk_label_set_justify (GTK_LABEL (pref_basic_update_lbl), GTK_JUSTIFY_RIGHT);
-	gtk_misc_set_alignment (GTK_MISC (pref_basic_update_lbl), 1, 0.5);
-*/
-
 	gtk_widget_show (pref_basic_update_hbox);
 
 	pref_basic_update_spin_adj = gtk_adjustment_new (30, 1, 3600, 5, 25, 1);
@@ -1084,7 +1081,7 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 
 	gtk_container_add (GTK_CONTAINER (frame), pref_basic_update_hbox);
 
-	frame = create_hig_catagory (pref_basic_vbox, _("Display"));
+	frame = create_hig_category (pref_basic_vbox, _("Display"));
 
 	vbox = gtk_vbox_new (FALSE, 6);
 
@@ -1115,7 +1112,11 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	gtk_container_add (GTK_CONTAINER (pref_notebook), pref_loc_hbox);
 
 	tree_label = gtk_label_new_with_mnemonic (_("_Select a location:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (tree_label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (tree_label), 0.0, 0.5);
+#endif
 	gtk_box_pack_start (GTK_BOX (pref_loc_hbox), tree_label, FALSE, FALSE, 0);
 
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
